Dependency<T> class

Constructors

Dependency({required Provider<T> parentProvider, required Provider<T> provider, required T updateFn(T)})

Properties

hashCode int
The hash code for this object.
no setterinherited
parentProvider Provider<T>
final
provider Provider<T>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
unsubscribedParent() → void

Operators

operator ==(Object other) bool
The equality operator.
inherited