ProviderRef<T> class

Constructors

ProviderRef({required Provider<T> provider})

Properties

hashCode int
The hash code for this object.
no setterinherited
provider Provider<T>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(Provider<T> otherProvider) → T
toString() String
A string representation of this object.
inherited
update(T updateFn(T)) → void
watch(Provider<T> otherProvider, T updateFn(T)) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited