Provider<T> class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
) → T -
toString(
) → String -
A string representation of this object.
inherited
-
unsubscribedDependency(
Provider< T> parentProvider) → void -
update(
T updateFn(T)) → void -
watch(
dynamic listener(T), {bool immediate = true}) → dynamic Function()
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createProvider<
T> (T createFn(ProviderRef< T> ), String name) → Provider<T>